DomainHTKCExploreBehavior<D> class

Behavior that generates semantic nodes for each domain.

Implemented types

Constructors

DomainHTKCExploreBehavior({VocalizationCallback<D>? vocalizationCallback, ExploreModeTrigger? exploreModeTrigger, double? minimumWidth, String? exploreModeEnabledAnnouncement, String? exploreModeDisabledAnnouncement})

Properties

exploreModeDisabledAnnouncement → String?
Optionally notify the OS when explore mode is disabled.
finalinherited
exploreModeEnabledAnnouncement → String?
Optionally notify the OS when explore mode is enabled.
finalinherited
exploreModeTrigger → ExploreModeTrigger
The gesture that activates explore mode. Defaults to long press.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
minimumWidth → double
Minimum width of the bounding box for the a11y focus.
finalinherited
role → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachTo(BaseChart<D> chart) → void
Injects the behavior into a chart.
createA11yNodes() → List<A11yNode>
Returns a list of A11yNodes for this chart.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFrom(BaseChart<D> chart) → void
Removes the behavior from a chart.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited